=== modified file 'lib/canonical/launchpad/security.py'
--- lib/canonical/launchpad/security.py	2011-08-31 19:45:02 +0000
+++ lib/canonical/launchpad/security.py	2011-09-05 06:23:05 +0000
@@ -175,6 +175,7 @@
     IBinaryPackageReleaseDownloadCount,
     )
 from lp.soyuz.interfaces.buildfarmbuildjob import IBuildFarmBuildJob
+from lp.soyuz.interfaces.distroarchseries import IDistroArchSeries
 from lp.soyuz.interfaces.packagecopyjob import IPlainPackageCopyJob
 from lp.soyuz.interfaces.packageset import (
     IPackageset,
@@ -1045,6 +1046,11 @@
         return EditByOwnersOrAdmins.checkAuthenticated(self, user)
 
 
+class ViewDistroArchSeries(AnonymousAuthorization):
+    """Anyone can view a DistroArchSeries."""
+    usedfor = IDistroArchSeries
+
+
 class ViewAnnouncement(AuthorizationBase):
     permission = 'launchpad.View'
     usedfor = IAnnouncement

=== added file 'lib/lp/soyuz/browser/tests/test_distroarchseries_webservice.py'
--- lib/lp/soyuz/browser/tests/test_distroarchseries_webservice.py	1970-01-01 00:00:00 +0000
+++ lib/lp/soyuz/browser/tests/test_distroarchseries_webservice.py	2011-09-05 16:22:34 +0000
@@ -0,0 +1,53 @@
+# Copyright 2010-2011 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+__metaclass__ = type
+
+from zope.security.management import endInteraction
+
+from canonical.testing.layers import DatabaseFunctionalLayer
+from lp.testing import (
+    launchpadlib_for,
+    ws_object,
+    TestCaseWithFactory,
+    )
+
+
+class TestDistroArchSeriesWebservice(TestCaseWithFactory):
+    """Unit Tests for 'DistroArchSeries' Webservice.
+    """
+    layer = DatabaseFunctionalLayer
+
+    def _makeDistroArchSeries(self):
+        """Create a `DistroSeries` object, that is prefilled with 1
+        architecture for testing purposes.
+
+        :return: a `DistroSeries` object.
+        """
+        distro = self.factory.makeDistribution()
+        distroseries = self.factory.makeDistroSeries(
+            distribution=distro)
+        self.factory.makeDistroArchSeries(
+            distroseries=distroseries)
+
+        return distroseries
+
+    def test_distroseries_architectures_anonymous(self):
+        """Test anonymous DistroArchSeries API Access."""
+        distroseries = self._makeDistroArchSeries()
+        endInteraction()
+        launchpad = launchpadlib_for('test', person=None, version='devel')
+        ws_distroseries = ws_object(launchpad, distroseries)
+        #Note, we test the length of architectures.entries, not
+        #architectures due to the removal of the entries by lazr
+        self.assertEqual(1, len(ws_distroseries.architectures.entries))
+
+    def test_distroseries_architectures_authenticated(self):
+        """Test authenticated DistroArchSeries API Access."""
+        distroseries = self._makeDistroArchSeries()
+        #Create a user to use the authenticated API
+        accessor = self.factory.makePerson()
+        launchpad = launchpadlib_for('test', accessor.name, version='devel')
+        ws_distroseries = ws_object(launchpad, distroseries)
+        #See note above regarding testing of length of .entries
+        self.assertEqual(1, len(ws_distroseries.architectures.entries))

